@@ -219,6 +219,6 @@ func attemptVpcCniDeletion(ctx context.Context, clusterConfig *api.ClusterConfig
 	logger.Debug("deleting kube-system/aws-node DaemonSet")
 	err := clientSet.AppsV1().DaemonSets("kube-system").Delete(ctx, "aws-node", metav1.DeleteOptions{})
 	if err != nil {
-		logger.Debug("failed to delete kube-system/aws-node DaemonSet: %w", err)
+		logger.Debug("failed to delete kube-system/aws-node DaemonSet: %v", err)
 	}
 }
